# -*- coding: utf-8 -*-

"""
xAPI module.
"""

from __future__ import absolute_import, unicode_literals

__version__ = "0.1.0"

default_app_config = ("integrated_channels.xapi.apps."  # pylint: disable=invalid-name
                      "XAPIConfig")
